#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-GpLcfBgqAAa6hTAlqMdifi
key:                  pantry-0.8.3-GpLcfBgqAAa6hTAlqMdifi
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  dbba82115679f4e1f2eb091eed711ee7
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-GpLcfBgqAAa6hTAlqMdifi
depends:
    Cabal-3.10.3.0 aeson-2.2.1.0-JgWKiJCfYvV9emVBTyf17S
    ansi-terminal-1.1-6lZFbttD1pdJPhvO6TaL8q base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-AHfP3mKLBNZ9oYj7hWg9jg
    casa-types-0.0.3-2hJ0fnO9WOmEQn1qrCctih
    conduit-1.3.6.1-2OrPc53D65FBPMl1LRGRl0
    conduit-extra-1.3.8-A1i86bJKALbGuXR2Jjl8gR containers-0.6.7
    crypton-1.0.4-218iYZKZyEH9qzNK0rIxzf
    crypton-conduit-0.2.3-JKgrWIB5JhgCOZY41i5dCU
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-YeyQBjFjzI2UujP5kQZqa
    generic-deriving-1.14.7-46cu681xn3SH6GQi3NkgOr
    hackage-security-0.6.3.2-Er7A2mbmqAeLtmDcO3473e
    hpack-0.38.0-LDoIIOmfgNEF2MM9SlknQa
    http-client-0.7.19-A1qGvj2MlivKXlcAABR34l
    http-client-tls-0.3.6.4-3iqTlLw34e0FRUZYw5kJuu
    http-conduit-2.3.9.1-2pvnK9eNS26BIIabHiNm90
    http-download-0.2.1.0-Dk5oJNfj2Zl5J7nFT9n5B2
    http-types-0.12.4-CCQmPdMOAQMGVpO7SZrjGJ
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-F4vpljQpQbT2777eQcDCfi
    path-0.9.6-bvdHUYGwbuCyNl0imDa1s
    path-io-1.8.2-HHx5IxmtlpD45wLCalOXdw
    persistent-2.14.5.2-DwKojrOzdNHH0d3oOZTELr
    persistent-sqlite-2.13.2.0-DetT9CZFIUDB5OUJGqewBX
    primitive-0.9.1.0-2iNENzVjdKAJSQQt3oRWsU
    resourcet-1.2.6-G3oEY3e1QnrAdomD3ZD7m7
    rio-0.1.24.0-JhfLBiYR2lJIQwP2I6JdTi
    rio-orphans-0.1.2.0-zEWnlNYUgn8jwYMWHoDs9
    rio-prettyprint-0.1.8.0-2KJJtq76HqYIX9cW9MlY6Q
    tar-conduit-0.4.1-2b7RBoeRpiD3vT0HLq23sw text-2.0.2
    text-metrics-0.3.3-GXiXj21IpFyKYMdUKILxLs time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-JHcud24i5tBJko1Lg5vR04
    unliftio-0.2.25.1-KBv4DTXvafxB4kek08uChL
    unordered-containers-0.2.20.1-HfKtyefgs0b2egKrxLGXU0
    vector-0.13.2.0-7eILYIgfGZSAohY3MIpZY
    yaml-0.11.11.2-6RHQVeQLUynCy8Xpa8UwTK
    zip-archive-0.4.3.2-2pO3C52wox7Iuhn2ZdkYMM

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

